@@ -12,52 +12,62 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id$ */
 
 #ifndef QGSMAPTOOLZOOM_H
 #define QGSMAPTOOLZOOM_H
 
 #include "qgsmaptool.h"
 #include <QRect>
+#include "qgis_gui.h"
 
 class QgsRubberBand;
 
-/** \ingroup gui
- * A map tool for zooming into the map.
- * @see QgsMapTool
+/**
+ * \ingroup gui
+ * \brief A map tool for zooming into the map.
+ * \see QgsMapTool
  */
 class GUI_EXPORT QgsMapToolZoom : public QgsMapTool
 {
+    Q_OBJECT
+
   public:
     //! constructor
-    QgsMapToolZoom( QgsMapCanvas* canvas, bool zoomOut );
+    QgsMapToolZoom( QgsMapCanvas *canvas, bool zoomOut );
+    ~QgsMapToolZoom() override;
 
-    ~QgsMapToolZoom();
-
-    //! Overridden mouse move event
-    virtual void canvasMoveEvent( QMouseEvent * e );
-
-    //! Overridden mouse press event
-    virtual void canvasPressEvent( QMouseEvent * e );
-
-    //! Overridden mouse release event
-    virtual void canvasReleaseEvent( QMouseEvent * e );
-
-    virtual bool isTransient() { return true; }
-
-    virtual void deactivate();
+    Flags flags() const override;
+    void canvasMoveEvent( QgsMapMouseEvent *e ) override;
+    void canvasPressEvent( QgsMapMouseEvent *e ) override;
+    void canvasReleaseEvent( QgsMapMouseEvent *e ) override;
+    void keyPressEvent( QKeyEvent *e ) override;
+    void keyReleaseEvent( QKeyEvent *e ) override;
+    void deactivate() override;
 
   protected:
     //! stores actual zoom rect
     QRect mZoomRect;
+    // minimum pixel size of diagonal of the zoom rectangle
+    int mMinPixelZoom = 20;
 
     //! indicates whether we're zooming in or out
     bool mZoomOut;
+    //! native tool
+    bool mNativeZoomOut;
 
     //! Flag to indicate a map canvas drag operation is taking place
     bool mDragging;
 
-    QgsRubberBand* mRubberBand;
+    //! Flag to indicate the user has canceled the current zoom operation
+    bool mCanceled = false;
+
+    QgsRubberBand *mRubberBand = nullptr;
+
+    QCursor mZoomOutCursor;
+    QCursor mZoomInCursor;
+
+  private:
+    void setZoomMode( bool zoomOut, bool force = false );
 };
 
 #endif
