@@ -39,9 +39,12 @@ class QgsPointXY;
 
 /**
  * \ingroup core
- * \brief QgsRasterProjector implements approximate projection support for
- * it calculates grid of points in source CRS for target CRS + extent
- * which are used to calculate affine transformation matrices.
+ * \brief Implements approximate projection support for optimised raster transformation.
+ *
+ * QgsRasterProjector calculates a grid of points in the source CRS for a specific target CRS and extent.
+ * These are used to calculate affine transformation matrices, which can be used instead of raw
+ * PROJ transformations for optimised bulk reprojection of points.
+ *
  * \class QgsRasterProjector
  */
 class CORE_EXPORT QgsRasterProjector : public QgsRasterInterface
@@ -71,7 +74,7 @@ class CORE_EXPORT QgsRasterProjector : public QgsRasterInterface
 
     /**
      * Sets the source and destination CRS
-     * \deprecated since QGIS 3.8, use transformContext version instead
+     * \deprecated QGIS 3.8. Use transformContext version instead.
      */
     Q_DECL_DEPRECATED void setCrs( const QgsCoordinateReferenceSystem &srcCRS, const QgsCoordinateReferenceSystem &destCRS,
                                    int srcDatumTransform = -1, int destDatumTransform = -1 ) SIP_DEPRECATED;
@@ -139,7 +142,7 @@ class ProjectorData
 {
   public:
     //! Initialize reprojector and calculate matrix
-    ProjectorData( const QgsRectangle &extent, int width, int height, QgsRasterInterface *input, const QgsCoordinateTransform &inverseCt, QgsRasterProjector::Precision precision );
+    ProjectorData( const QgsRectangle &extent, int width, int height, QgsRasterInterface *input, const QgsCoordinateTransform &inverseCt, QgsRasterProjector::Precision precision, QgsRasterBlockFeedback *feedback = nullptr );
     ~ProjectorData();
 
     ProjectorData( const ProjectorData &other ) = delete;
@@ -196,12 +199,14 @@ class ProjectorData
 
     /**
      * \brief check error along columns
-      * returns TRUE if within threshold */
+     * returns TRUE if within threshold
+    */
     bool checkCols( const QgsCoordinateTransform &ct );
 
     /**
      * \brief check error along rows
-      * returns TRUE if within threshold */
+     * returns TRUE if within threshold
+    */
     bool checkRows( const QgsCoordinateTransform &ct );
 
     //! Calculate array of src helper points
@@ -211,11 +216,12 @@ class ProjectorData
     void nextHelper();
 
     //! Gets mCPMatrix as string
-    QString cpToString();
+    QString cpToString() const;
 
     /**
      * Use approximation (requested precision is Approximate and it is possible to calculate
-     *  an approximation matrix with a sufficient precision) */
+     * an approximation matrix with a sufficient precision).
+    */
     bool mApproximate;
 
     //! Transformation from destination CRS to source CRS
